Data Types, Structs, Enums, and Constants๏ƒ

struct Npp16f๏ƒ

Workarounds for cuda_fp16.h C incompatibility Npp16f.

Public Members

short fp16๏ƒ

Original Cuda fp16 data size and format.

struct Npp16f_2๏ƒ

Npp16f_2.

Public Members

short fp16_0๏ƒ

Original Cuda fp16 data size and format.

short fp16_1๏ƒ

Original Cuda fp16 data size and format.

enum NppiInterpolationMode๏ƒ

Filtering methods.

Values:

enumerator NPPI_INTER_UNDEFINED๏ƒ

Undefined filtering interpolation mode.

enumerator NPPI_INTER_NN๏ƒ

Nearest neighbor filtering.

enumerator NPPI_INTER_LINEAR๏ƒ

Linear interpolation.

enumerator NPPI_INTER_CUBIC๏ƒ

Cubic interpolation.

enumerator NPPI_INTER_CUBIC2P_BSPLINE๏ƒ

Two-parameter cubic filter (B=1, C=0)

enumerator NPPI_INTER_CUBIC2P_CATMULLROM๏ƒ

Two-parameter cubic filter (B=0, C=1/2)

enumerator NPPI_INTER_CUBIC2P_B05C03๏ƒ

Two-parameter cubic filter (B=1/2, C=3/10)

enumerator NPPI_INTER_SUPER๏ƒ

Super sampling.

enumerator NPPI_INTER_LANCZOS๏ƒ

Lanczos filtering.

enumerator NPPI_INTER_LANCZOS3_ADVANCED๏ƒ

Generic Lanczos filtering with order 3.

enumerator NPPI_SMOOTH_EDGE๏ƒ

Smooth edge filtering.

enum NppiBayerGridPosition๏ƒ

Bayer Grid Position Registration.

Values:

enumerator NPPI_BAYER_BGGR๏ƒ

Default registration position BGGR.

enumerator NPPI_BAYER_RGGB๏ƒ

Registration position RGGB.

enumerator NPPI_BAYER_GBRG๏ƒ

Registration position GBRG.

enumerator NPPI_BAYER_GRBG๏ƒ

Registration position GRBG.

enum NppiMaskSize๏ƒ

Fixed filter-kernel sizes.

Values:

enumerator NPP_MASK_SIZE_1_X_3๏ƒ

1 X 3 filter mask size.

enumerator NPP_MASK_SIZE_1_X_5๏ƒ

1 X 5 filter mask size.

enumerator NPP_MASK_SIZE_3_X_1๏ƒ

3 X 1 filter mask size, leaving space for more 1 X N type enum values.

enumerator NPP_MASK_SIZE_5_X_1๏ƒ

5 X 1 filter mask size.

enumerator NPP_MASK_SIZE_3_X_3๏ƒ

3 X 3 filter mask size, leaving space for more N X 1 type enum values.

enumerator NPP_MASK_SIZE_5_X_5๏ƒ

5 X 5 filter mask size.

enumerator NPP_MASK_SIZE_7_X_7๏ƒ

7 X 7 filter mask size.

enumerator NPP_MASK_SIZE_9_X_9๏ƒ

9 X 9 filter mask size.

enumerator NPP_MASK_SIZE_11_X_11๏ƒ

11 X 11 filter mask size.

enumerator NPP_MASK_SIZE_13_X_13๏ƒ

13 X 13 filter mask size.

enumerator NPP_MASK_SIZE_15_X_15๏ƒ

15 X 15 filter mask size.

enum NppiDifferentialKernel๏ƒ

Differential Filter types.

Values:

enumerator NPP_FILTER_SOBEL๏ƒ

Differential kernel filter type sobel.

enumerator NPP_FILTER_SCHARR๏ƒ

Differential kernel filter type scharr.

enum NppStatus๏ƒ

Error Status Codes.

Almost all NPP function return error-status information using these return codes. Negative return codes indicate errors, positive return codes indicate warnings, a return code of 0 indicates success.

Values:

enumerator NPP_LIBRARY_VERSION_MISMATCH_ERROR๏ƒ

Application and NPP library version mismatch.

enumerator NPP_INVALID_HOST_POINTER_ERROR๏ƒ

Invalid host memory pointer error.

enumerator NPP_INVALID_DEVICE_POINTER_ERROR๏ƒ

Invalid device memory pointer error.

enumerator NPP_LUT_PALETTE_BITSIZE_ERROR๏ƒ

Color look up table bitsize error.

enumerator NPP_ZC_MODE_NOT_SUPPORTED_ERROR๏ƒ

ZeroCrossing mode not supported error.

enumerator NPP_NOT_SUFFICIENT_COMPUTE_CAPABILITY๏ƒ

Not sufficient Cuda compute capability error.

enumerator NPP_TEXTURE_BIND_ERROR๏ƒ

Texture bind error.

enumerator NPP_WRONG_INTERSECTION_ROI_ERROR๏ƒ

Wrong intersection region of interest error.

enumerator NPP_HAAR_CLASSIFIER_PIXEL_MATCH_ERROR๏ƒ

Haar classifier pixel match error.

enumerator NPP_MEMFREE_ERROR๏ƒ

Memory free request error.

enumerator NPP_MEMSET_ERROR๏ƒ

Memory set request error.

enumerator NPP_MEMCPY_ERROR๏ƒ

Memory copy request error.

enumerator NPP_ALIGNMENT_ERROR๏ƒ

Memory alignment error.

enumerator NPP_CUDA_KERNEL_EXECUTION_ERROR๏ƒ

Cuda kernel execution error, most commonly Cuda kernel launch error.

enumerator NPP_STREAM_CTX_ERROR๏ƒ

Non CTX function support has been deprecated.

enumerator NPP_ROUND_MODE_NOT_SUPPORTED_ERROR๏ƒ

Unsupported round mode.

enumerator NPP_QUALITY_INDEX_ERROR๏ƒ

Image pixels are constant for quality index.

enumerator NPP_RESIZE_NO_OPERATION_ERROR๏ƒ

One of the output image dimensions is less than 1 pixel.

enumerator NPP_OVERFLOW_ERROR๏ƒ

Number overflows the upper or lower limit of the data type.

enumerator NPP_NOT_EVEN_STEP_ERROR๏ƒ

Step value is not pixel multiple.

enumerator NPP_HISTOGRAM_NUMBER_OF_LEVELS_ERROR๏ƒ

Number of levels for histogram is less than 2.

enumerator NPP_LUT_NUMBER_OF_LEVELS_ERROR๏ƒ

Number of levels for LUT is less than 2.

enumerator NPP_ZERO_MASK_VALUE_ERROR๏ƒ

All values of the mask are zero.

enumerator NPP_CORRUPTED_DATA_ERROR๏ƒ

Processed data is corrupted.

enumerator NPP_CHANNEL_ORDER_ERROR๏ƒ

Wrong order of the destination channels.

enumerator NPP_DATA_TYPE_ERROR๏ƒ

Data type is incorrect or not supported.

enumerator NPP_QUADRANGLE_ERROR๏ƒ

The quadrangle is nonconvex or degenerates into triangle, line or point.

enumerator NPP_RECTANGLE_ERROR๏ƒ

Size of the rectangle region is less than or equal to 1.

enumerator NPP_COEFFICIENT_ERROR๏ƒ

Unallowable values of the transformation coefficients.

enumerator NPP_NUMBER_OF_CHANNELS_ERROR๏ƒ

Bad or unsupported number of channels.

enumerator NPP_COI_ERROR๏ƒ

Channel of interest is not 1, 2, or 3.

enumerator NPP_DIVISOR_ERROR๏ƒ

Divisor is equal to zero.

enumerator NPP_CHANNEL_ERROR๏ƒ

Illegal channel index.

enumerator NPP_STRIDE_ERROR๏ƒ

Stride is less than the row length.

enumerator NPP_ANCHOR_ERROR๏ƒ

Anchor point is outside mask.

enumerator NPP_MASK_SIZE_ERROR๏ƒ

Lower bound is larger than upper bound.

enumerator NPP_RESIZE_FACTOR_ERROR๏ƒ
enumerator NPP_INTERPOLATION_ERROR๏ƒ
enumerator NPP_MIRROR_FLIP_ERROR๏ƒ
enumerator NPP_MOMENT_00_ZERO_ERROR๏ƒ
enumerator NPP_THRESHOLD_NEGATIVE_LEVEL_ERROR๏ƒ
enumerator NPP_THRESHOLD_ERROR๏ƒ
enumerator NPP_FFT_FLAG_ERROR๏ƒ
enumerator NPP_FFT_ORDER_ERROR๏ƒ
enumerator NPP_STEP_ERROR๏ƒ

Step is less or equal zero.

enumerator NPP_NOT_SUPPORTED_MODE_ERROR๏ƒ

Not supported mode error.

enumerator NPP_CONTEXT_MATCH_ERROR๏ƒ
enumerator NPP_SCALE_RANGE_ERROR๏ƒ
enumerator NPP_OUT_OFF_RANGE_ERROR๏ƒ
enumerator NPP_DIVIDE_BY_ZERO_ERROR๏ƒ
enumerator NPP_MEMORY_ALLOCATION_ERR๏ƒ
enumerator NPP_NULL_POINTER_ERROR๏ƒ
enumerator NPP_RANGE_ERROR๏ƒ
enumerator NPP_SIZE_ERROR๏ƒ
enumerator NPP_BAD_ARGUMENT_ERROR๏ƒ
enumerator NPP_NO_MEMORY_ERROR๏ƒ
enumerator NPP_NOT_IMPLEMENTED_ERROR๏ƒ
enumerator NPP_ERROR๏ƒ
enumerator NPP_ERROR_RESERVED๏ƒ
enumerator NPP_NO_ERROR๏ƒ

Error free operation.

enumerator NPP_SUCCESS๏ƒ

Successful operation (same as NPP_NO_ERROR)

enumerator NPP_NO_OPERATION_WARNING๏ƒ

Indicates that no operation was performed.

enumerator NPP_DIVIDE_BY_ZERO_WARNING๏ƒ

Divisor is zero however does not terminate the execution.

enumerator NPP_AFFINE_QUAD_INCORRECT_WARNING๏ƒ

Indicates that the quadrangle passed to one of affine warping functions doesnโ€™t have necessary properties.

First 3 vertices are used, the fourth vertex discarded.

enumerator NPP_WRONG_INTERSECTION_ROI_WARNING๏ƒ

The given ROI has no intersection with either the source or destination ROI.

Thus no operation was performed.

enumerator NPP_WRONG_INTERSECTION_QUAD_WARNING๏ƒ

The given quadrangle has no intersection with either the source or destination ROI.

Thus no operation was performed.

enumerator NPP_DOUBLE_SIZE_WARNING๏ƒ

Image size isnโ€™t multiple of two.

Indicates that in case of 422/411/420 sampling the ROI width/height was modified for proper processing.

enumerator NPP_MISALIGNED_DST_ROI_WARNING๏ƒ

Speed reduction due to uncoalesced memory accesses warning.

struct NppLibraryVersion๏ƒ

NPPLibraryVersion This struct contains the NPP Library Version information.

Public Members

int major๏ƒ

Major version number.

int minor๏ƒ

Minor version number.

int build๏ƒ

Build number.

This reflects the nightly build this release was made from.

typedef unsigned char Npp8u๏ƒ

8-bit unsigned chars

typedef signed char Npp8s๏ƒ

8-bit signed chars

typedef unsigned short Npp16u๏ƒ

16-bit unsigned integers

typedef short Npp16s๏ƒ

16-bit signed integers

typedef unsigned int Npp32u๏ƒ

32-bit unsigned integers

typedef int Npp32s๏ƒ

32-bit signed integers

typedef unsigned long long Npp64u๏ƒ

64-bit unsigned integers

typedef long long Npp64s๏ƒ

64-bit signed integers

typedef float Npp32f๏ƒ

32-bit (IEEE) floating-point numbers

typedef double Npp64f๏ƒ

64-bit floating-point numbers

struct Npp8uc๏ƒ

Complex Number This struct represents an unsigned char complex number.

Public Members

Npp8u re๏ƒ

Real part.

Npp8u im๏ƒ

Imaginary part.

struct Npp16uc๏ƒ

Complex Number This struct represents an unsigned short complex number.

Public Members

Npp16u re๏ƒ

Real part.

Npp16u im๏ƒ

Imaginary part.

struct Npp16sc๏ƒ

Complex Number This struct represents a short complex number.

Public Members

Npp16s re๏ƒ

Real part.

Npp16s im๏ƒ

Imaginary part.

struct Npp32uc๏ƒ

Complex Number This struct represents an unsigned int complex number.

Public Members

Npp32u re๏ƒ

Real part.

Npp32u im๏ƒ

Imaginary part.

struct Npp32sc๏ƒ

Complex Number This struct represents a signed int complex number.

Public Members

Npp32s re๏ƒ

Real part.

Npp32s im๏ƒ

Imaginary part.

struct Npp32fc๏ƒ

Complex Number This struct represents a single floating-point complex number.

Public Members

Npp32f re๏ƒ

Real part.

Npp32f im๏ƒ

Imaginary part.

struct Npp64sc๏ƒ

Complex Number This struct represents a long long complex number.

Public Members

Npp64s re๏ƒ

Real part.

Npp64s im๏ƒ

Imaginary part.

struct Npp64fc๏ƒ

Complex Number This struct represents a double floating-point complex number.

Public Members

Npp64f re๏ƒ

Real part.

Npp64f im๏ƒ

Imaginary part.

enum NppDataType๏ƒ

Data types for nppiPlus functions.

Values:

enumerator NPP_8U๏ƒ

8-bit unsigned integer data type

enumerator NPP_8S๏ƒ

8-bit signed integer data type

enumerator NPP_16U๏ƒ

16-bit unsigned integer data type

enumerator NPP_16S๏ƒ

16-bit signed integer data type

enumerator NPP_32U๏ƒ

32-bit unsigned integer data type

enumerator NPP_32S๏ƒ

32-bit signed integer data type

enumerator NPP_64U๏ƒ

64-bit unsigned integer data type

enumerator NPP_64S๏ƒ

64-bit signed integer data type

enumerator NPP_16F๏ƒ

16-bit original Cuda floating point data type

enumerator NPP_32F๏ƒ

32-bit floating point data type

enumerator NPP_64F๏ƒ

64-bit double precision floating point data type

enum NppiChannels๏ƒ

Image channel counts for nppiPlus functions.

Values:

enumerator NPP_CH_1๏ƒ

Single channel per pixel data.

enumerator NPP_CH_2๏ƒ

Two channel per pixel data.

enumerator NPP_CH_3๏ƒ

Three channel per pixel data.

enumerator NPP_CH_4๏ƒ

Four channel per pixel data.

enumerator NPP_CH_A4๏ƒ

Four channel per pixel data with alpha.

enumerator NPP_CH_P2๏ƒ

Two channel single channel per plane pixel data.

enumerator NPP_CH_P3๏ƒ

Three channel single channel per plane pixel data.

enumerator NPP_CH_P4๏ƒ

Four channel single channel per plane pixel data.

NPP_MIN_8U๏ƒ

Minimum 8-bit unsigned integer.

NPP_MAX_8U๏ƒ

Maximum 8-bit unsigned integer.

NPP_MIN_16U๏ƒ

Minimum 16-bit unsigned integer.

NPP_MAX_16U๏ƒ

Maximum 16-bit unsigned integer.

NPP_MIN_32U๏ƒ

Minimum 32-bit unsigned integer.

NPP_MAX_32U๏ƒ

Maximum 32-bit unsigned integer.

NPP_MIN_64U๏ƒ

Minimum 64-bit unsigned integer.

NPP_MAX_64U๏ƒ

Maximum 64-bit unsigned integer.

NPP_MIN_8S๏ƒ

Minimum 8-bit signed integer.

NPP_MAX_8S๏ƒ

Maximum 8-bit signed integer.

NPP_MIN_16S๏ƒ

Minimum 16-bit signed integer.

NPP_MAX_16S๏ƒ

Maximum 16-bit signed integer.

NPP_MIN_32S๏ƒ

Minimum 32-bit signed integer.

NPP_MAX_32S๏ƒ

Maximum 32-bit signed integer.

NPP_MIN_64S๏ƒ

Minimum 64-bit signed integer.

NPP_MAX_64S๏ƒ

Minimum 64-bit signed integer.

NPP_MINABS_32F๏ƒ

Smallest positive 32-bit floating point value.

NPP_MAXABS_32F๏ƒ

Largest positive 32-bit floating point value.

NPP_MINABS_64F๏ƒ

Smallest positive 64-bit floating point value.

NPP_MAXABS_64F๏ƒ

Largest positive 64-bit floating point value.

struct NppiPoint๏ƒ

2D Point

Public Members

int x๏ƒ

x-coordinate.

int y๏ƒ

y-coordinate.

struct NppiPoint32f๏ƒ

2D Npp32f Point

Public Members

Npp32f x๏ƒ

x-coordinate.

Npp32f y๏ƒ

y-coordinate.

struct NppiPoint64f๏ƒ

2D Npp64f Point

Public Members

Npp64f x๏ƒ

x-coordinate.

Npp64f y๏ƒ

y-coordinate.

struct NppPointPolar๏ƒ

2D Polar Point

Public Members

Npp32f rho๏ƒ

Polar rho value.

Npp32f theta๏ƒ

Polar theta value.

struct NppiSize๏ƒ

2D Size This struct typically represents the size of a a rectangular region in two space.

Public Members

int width๏ƒ

Rectangle width.

int height๏ƒ

Rectangle height.

struct NppiRect๏ƒ

2D Rectangle This struct contains position and size information of a rectangle in two space.

The rectangleโ€™s position is usually signified by the coordinate of its upper-left corner.

Public Members

int x๏ƒ

x-coordinate of upper left corner (lowest memory address).

int y๏ƒ

y-coordinate of upper left corner (lowest memory address).

int width๏ƒ

Rectangle width.

int height๏ƒ

Rectangle height.

enum NppiAxis๏ƒ

nppiMirror direction controls

Values:

enumerator NPP_HORIZONTAL_AXIS๏ƒ

Flip around horizontal axis in mirror function.

enumerator NPP_VERTICAL_AXIS๏ƒ

Flip around vertical axis in mirror function.

enumerator NPP_BOTH_AXIS๏ƒ

Flip around both axes in mirror function.

enum NppCmpOp๏ƒ

Pixel comparison control values.

Values:

enumerator NPP_CMP_LESS๏ƒ

Threshold test for less than.

enumerator NPP_CMP_LESS_EQ๏ƒ

Threshold test for less than or equal.

enumerator NPP_CMP_EQ๏ƒ

Threshold test for equal.

enumerator NPP_CMP_GREATER_EQ๏ƒ

Threshold test for greater than or equal.

enumerator NPP_CMP_GREATER๏ƒ

Threshold test for greater than.

enum NppRoundMode๏ƒ

Rounding Modes.

The enumerated rounding modes are used by a large number of NPP primitives to allow the user to specify the method by which fractional values are converted to integer values. Also see Rounding Modes.

For NPP release 5.5 new names for the three rounding modes are introduced that are based on the naming conventions for rounding modes set forth in the IEEE-754 floating-point standard. Developers are encouraged to use the new, longer names to be future proof as the legacy names will be deprecated in subsequent NPP releases.

Values:

enumerator NPP_RND_NEAR๏ƒ

Round to the nearest even integer.

All fractional numbers are rounded to their nearest integer. The ambiguous cases (i.e. <integer>.5) are rounded to the closest even integer. E.g.

  • roundNear(0.5) = 0

  • roundNear(0.6) = 1

  • roundNear(1.5) = 2

  • roundNear(-1.5) = -2

enumerator NPP_ROUND_NEAREST_TIES_TO_EVEN๏ƒ

Alias name for NPP_RND_NEAR.

enumerator NPP_RND_FINANCIAL๏ƒ

Round according to financial rule.

All fractional numbers are rounded to their nearest integer. The ambiguous cases (i.e. <integer>.5) are rounded away from zero. E.g.

  • roundFinancial(0.4) = 0

  • roundFinancial(0.5) = 1

  • roundFinancial(-1.5) = -2

enumerator NPP_ROUND_NEAREST_TIES_AWAY_FROM_ZERO๏ƒ

Alias name for NPP_RND_FINANCIAL.

enumerator NPP_RND_ZERO๏ƒ

Round towards zero (truncation).

All fractional numbers of the form <integer>.<decimals> are truncated to <integer>.

  • roundZero(1.5) = 1

  • roundZero(1.9) = 1

  • roundZero(-2.5) = -2

enumerator NPP_ROUND_TOWARD_ZERO๏ƒ

Alias name for NPP_RND_ZERO.

enum NppiBorderType๏ƒ

Supported image border modes.

Values:

enumerator NPP_BORDER_UNDEFINED๏ƒ

Image border type undefined.

enumerator NPP_BORDER_NONE๏ƒ

Image border type none.

enumerator NPP_BORDER_CONSTANT๏ƒ

Image border type constant value.

enumerator NPP_BORDER_REPLICATE๏ƒ

Image border type replicate border pixels.

enumerator NPP_BORDER_WRAP๏ƒ

Image border type wrap border pixels.

enumerator NPP_BORDER_MIRROR๏ƒ

Image border type mirror border pixels (IPP mirrored border / OpenCV BORDER_REFLECT_101): gfedcb|abcdefgh|gfedcba โ€” edge pixel is NOT repeated.

enumerator NPP_BORDER_MIRROR_REFL๏ƒ

Image border type mirror with replication (IPP mirrored border with replication / OpenCV BORDER_REFLECT): fedcba|abcdefgh|hgfedcba โ€” edge pixel IS repeated.

enum NppHintAlgorithm๏ƒ

Hints.

Values:

enumerator NPP_ALG_HINT_NONE๏ƒ

Hint none, currently these are all ignored.

enumerator NPP_ALG_HINT_FAST๏ƒ

Hint fast, currently these are all ignored.

enumerator NPP_ALG_HINT_ACCURATE๏ƒ

Hint accurate, currently these are all ignored.

enum NppiAlphaOp๏ƒ

Alpha composition mode controls.

Values:

enumerator NPPI_OP_ALPHA_OVER๏ƒ

Alpha composition over operation.

enumerator NPPI_OP_ALPHA_IN๏ƒ

Alpha composition in operation.

enumerator NPPI_OP_ALPHA_OUT๏ƒ

Alpha composition out operation.

enumerator NPPI_OP_ALPHA_ATOP๏ƒ

Alpha composition atop operation.

enumerator NPPI_OP_ALPHA_XOR๏ƒ

Alpha composition xor operation.

enumerator NPPI_OP_ALPHA_PLUS๏ƒ

Alpha composition plus operation.

enumerator NPPI_OP_ALPHA_OVER_PREMUL๏ƒ

Alpha composition over premultiply operation.

enumerator NPPI_OP_ALPHA_IN_PREMUL๏ƒ

Alpha composition in premultiply operation.

enumerator NPPI_OP_ALPHA_OUT_PREMUL๏ƒ

Alpha composition out premultiply operation.

enumerator NPPI_OP_ALPHA_ATOP_PREMUL๏ƒ

Alpha composition atop premultiply operation.

enumerator NPPI_OP_ALPHA_XOR_PREMUL๏ƒ

Alpha composition xor premultiply operation.

enumerator NPPI_OP_ALPHA_PLUS_PREMUL๏ƒ

Alpha composition plus premultiply operation.

enumerator NPPI_OP_ALPHA_PREMUL๏ƒ

Alpha composition premultiply operation.

struct NppiHOGConfig๏ƒ

The NppiHOGConfig structure defines the configuration parameters for the HOG descriptor:

Public Members

int cellSize๏ƒ

square cell size (pixels).

int histogramBlockSize๏ƒ

square histogram block size (pixels).

int nHistogramBins๏ƒ

required number of histogram bins.

NppiSize detectionWindowSize๏ƒ

detection window size (pixels).

NPP_HOG_MAX_CELL_SIZE๏ƒ

HOG Cell controls.

max horizontal/vertical pixel size of cell.

NPP_HOG_MAX_BLOCK_SIZE๏ƒ

max horizontal/vertical pixel size of block.

NPP_HOG_MAX_BINS_PER_CELL๏ƒ

max number of histogram bins.

NPP_HOG_MAX_CELLS_PER_DESCRIPTOR๏ƒ

max number of cells in a descriptor window.

NPP_HOG_MAX_OVERLAPPING_BLOCKS_PER_DESCRIPTOR๏ƒ

max number of overlapping blocks in a descriptor window.

NPP_HOG_MAX_DESCRIPTOR_LOCATIONS_PER_CALL๏ƒ

max number of descriptor window locations per function call.

struct NppiHaarClassifier_32f๏ƒ

Data structure for HaarClassifier_32f.

Public Members

int numClassifiers๏ƒ

number of classifiers.

Npp32s *classifiers๏ƒ

packed classifier data 40 bytes each.

size_t classifierStep๏ƒ

packed classifier byte step.

NppiSize classifierSize๏ƒ

packed classifier size.

Npp32s *counterDevice๏ƒ

counter device.

struct NppiHaarBuffer๏ƒ

Data structure for Haar buffer.

Public Members

int haarBufferSize๏ƒ

size of the buffer

Npp32s *haarBuffer๏ƒ

buffer

enum NppsZCType๏ƒ

Signal sign operations.

Values:

enumerator nppZCR๏ƒ

sign change

enumerator nppZCXor๏ƒ

sign change XOR

enumerator nppZCC๏ƒ

sign change count_0

enum NppiHuffmanTableType๏ƒ

HuffMan Table controls.

Values:

enumerator nppiDCTable๏ƒ

DC Table.

enumerator nppiACTable๏ƒ

AC Table.

enum NppiNorm๏ƒ

Norm controls.

Values:

enumerator nppiNormInf๏ƒ

maximum

enumerator nppiNormL1๏ƒ

sum

enumerator nppiNormL2๏ƒ

square root of sum of squares

struct NppiConnectedRegion๏ƒ

Data structure of connected pixel region information.

Public Members

NppiRect oBoundingBox๏ƒ

x, y, width, height == left, top, right, and bottom pixel coordinates

Npp32u nConnectedPixelCount๏ƒ

total number of pixels in connected region

Npp32u aSeedPixelValue[3]๏ƒ

original pixel value of seed pixel, 1 or 3 channel

struct NppiImageDescriptor๏ƒ

General image descriptor.

Defines the basic parameters of an image, including data pointer, step, and image size. This can be used by both source and destination images.

Public Members

void *pData๏ƒ

device memory pointer to the image

int nStep๏ƒ

step size

NppiSize oSize๏ƒ

width and height of the image

struct NppiBufferDescriptor๏ƒ

struct NppiBufferDescriptor

Public Members

void *pData๏ƒ

per image device memory pointer to the corresponding buffer

int nBufferSize๏ƒ

allocated buffer size

struct NppiCompressedMarkerLabelsInfo๏ƒ

Provides details of uniquely labeled pixel regions of interest returned by CompressedLabelMarkersUF function.

Public Members

Npp32u nMarkerLabelPixelCount๏ƒ

total number of pixels in this connected pixel region

Npp32u nContourPixelCount๏ƒ

total number of pixels in this connected pixel region contour

Npp32u nContourPixelsFound๏ƒ

total number of pixels in this connected pixel region contour found during geometry search

NppiPoint oContourFirstPixelLocation๏ƒ

image geometric x and y location of the first pixel in the contour

NppiRect oMarkerLabelBoundingBox๏ƒ

bounding box of this connected pixel region expressed as leftmostX, topmostY, rightmostX, and bottommostY

struct NppiContourBlockSegment๏ƒ

Provides details of contour pixel grid map location and association.

Public Members

Npp32u nMarkerLabelID๏ƒ

this connected pixel region contour ID

Npp32u nContourPixelCount๏ƒ

total number of pixels in this connected pixel region contour

Npp32u nContourStartingPixelOffset๏ƒ

base offset of starting pixel in the overall contour pixel list

Npp32u nSegmentNum๏ƒ

relative block segment number within this particular contour ID

struct NppiContourPixelGeometryInfo๏ƒ

Provides contour (boundary) geometry info of uniquely labeled pixel regions returned by nppiCompressedMarkerLabelsUFInfo function in host memory in counterclockwise order relative to contour interiors.

Public Members

NppiPoint oContourOrderedGeometryLocation๏ƒ

image geometry X and Y location in requested output order

NppiPoint oContourPrevPixelLocation๏ƒ

image geometry X and Y location of previous contour pixel

NppiPoint oContourCenterPixelLocation๏ƒ

image geometry X and Y location of center contour pixel

NppiPoint oContourNextPixelLocation๏ƒ

image geometry X and Y location of next contour pixel

Npp32s nOrderIndex๏ƒ

contour pixel counterclockwise order index in geometry list

Npp32s nReverseOrderIndex๏ƒ

contour pixel clockwise order index in geometry list

Npp32u nFirstIndex๏ƒ

index of first ordered contour pixel in this subgroup

Npp32u nLastIndex๏ƒ

index of last ordered contour pixel in this subgroup

Npp32u nNextContourPixelIndex๏ƒ

index of next ordered contour pixel in NppiContourPixelGeometryInfo list

Npp32u nPrevContourPixelIndex๏ƒ

index of previous ordered contour pixel in NppiContourPixelGeometryInfo list

Npp8u nPixelAlreadyUsed๏ƒ

this test pixel is has already been used

Npp8u nAlreadyLinked๏ƒ

this test pixel is already linked to center pixel

Npp8u nAlreadyOutput๏ƒ

this pixel has already been output in geometry list

Npp8u nContourInteriorDirection๏ƒ

direction of contour region interior

NPP_CONTOUR_DIRECTION_SOUTH_EAST๏ƒ

Provides contour (boundary) direction info of uniquely labeled pixel regions returned by CompressedLabelMarkersUF function.

Contour direction south east

NPP_CONTOUR_DIRECTION_SOUTH๏ƒ

Contour direction south.

NPP_CONTOUR_DIRECTION_SOUTH_WEST๏ƒ

Contour direction south west.

NPP_CONTOUR_DIRECTION_WEST๏ƒ

Contour direction west.

NPP_CONTOUR_DIRECTION_EAST๏ƒ

Contour direction east.

NPP_CONTOUR_DIRECTION_NORTH_EAST๏ƒ

Contour direction north east.

NPP_CONTOUR_DIRECTION_NORTH๏ƒ

Contour direction north.

NPP_CONTOUR_DIRECTION_NORTH_WEST๏ƒ

Contour direction north west.

NPP_CONTOUR_DIRECTION_ANY_NORTH๏ƒ

Provides contour (boundary) diagonal direction info of uniquely labeled pixel regions returned by CompressedLabelMarkersUF function.

Contour direction any north

NPP_CONTOUR_DIRECTION_ANY_WEST๏ƒ

Contour direction any west.

NPP_CONTOUR_DIRECTION_ANY_SOUTH๏ƒ

Contour direction any south.

NPP_CONTOUR_DIRECTION_ANY_EAST๏ƒ

Contour direction any east.

struct NppiContourPixelDirectionInfo๏ƒ

Data structure for contour pixel direction information.

Public Members

Npp32u nMarkerLabelID๏ƒ

MarkerLabelID of contour interior connected region.

Npp8u nContourDirectionCenterPixel๏ƒ

provides current center contour pixel input and output direction info

Npp8u nContourInteriorDirectionCenterPixel๏ƒ

provides current center contour pixel region interior direction info

Npp8u nConnected๏ƒ

direction to directly connected contour pixels, 0 if not connected

Npp8u nGeometryInfoIsValid๏ƒ

direction to directly connected contour pixels, 0 if not connected

NppiContourPixelGeometryInfo oContourPixelGeometryInfo๏ƒ

Pixel geometry info structure.

NppiPoint nEast1๏ƒ

Pixel coordinate values in each direction.

NppiPoint nNorthEast1๏ƒ

Pixel coordinate values in each direction.

NppiPoint nNorth1๏ƒ

Pixel coordinate values in each direction.

NppiPoint nNorthWest1๏ƒ

Pixel coordinate values in each direction.

NppiPoint nWest1๏ƒ

Pixel coordinate values in each direction.

NppiPoint nSouthWest1๏ƒ

Pixel coordinate values in each direction.

NppiPoint nSouth1๏ƒ

Pixel coordinate values in each direction.

NppiPoint nSouthEast1๏ƒ

Pixel coordinate values in each direction.

Npp8u nTest1EastConnected๏ƒ

East connected flag.

Npp8u nTest1NorthEastConnected๏ƒ

North east connected flag.

Npp8u nTest1NorthConnected๏ƒ

North connected flag.

Npp8u nTest1NorthWestConnected๏ƒ

North west connected flag.

Npp8u nTest1WestConnected๏ƒ

West connected flag.

Npp8u nTest1SouthWestConnected๏ƒ

South west connected flag.

Npp8u nTest1SouthConnected๏ƒ

South connected flag.

Npp8u nTest1SouthEastConnected๏ƒ

South east connected flag.

struct NppiContourTotalsInfo๏ƒ

Data structure for contour total counts.

Public Members

Npp32u nTotalImagePixelContourCount๏ƒ

total number of contour pixels in image

Npp32u nLongestImageContourPixelCount๏ƒ

longest per contour pixel count in image

enum NppiWatershedSegmentBoundaryType๏ƒ

Provides control of the type of segment boundaries, if any, added to the image generated by the watershed segmentation function.

Values:

enumerator NPP_WATERSHED_SEGMENT_BOUNDARIES_NONE๏ƒ

Image watershed segment boundary type none.

enumerator NPP_WATERSHED_SEGMENT_BOUNDARIES_BLACK๏ƒ

Image watershed segment boundary type black.

enumerator NPP_WATERSHED_SEGMENT_BOUNDARIES_WHITE๏ƒ

Image watershed segment boundary type white.

enumerator NPP_WATERSHED_SEGMENT_BOUNDARIES_CONTRAST๏ƒ

Image watershed segment boundary type contrasting intensity.

enumerator NPP_WATERSHED_SEGMENT_BOUNDARIES_ONLY๏ƒ

Image watershed segment boundary type render boundaries only.

struct NppStreamContext๏ƒ

Application Managed Stream Context๏ƒ

NPP stream context structure must be filled in by application.

Populate all fields as shown below. Set hWorkspace = 0 to opt out of the optional workspace cache (pass a handle from nppiWorkspaceCreate() to enable it):

NppStreamContext ctx;
ctx.hStream = myStream;
cudaGetDevice(&ctx.nCudaDeviceId);
cudaDeviceProp props;
cudaGetDeviceProperties(&props, ctx.nCudaDeviceId);
ctx.nMultiProcessorCount               = props.multiProcessorCount;
ctx.nMaxThreadsPerMultiProcessor       = props.maxThreadsPerMultiProcessor;
ctx.nMaxThreadsPerBlock                = props.maxThreadsPerBlock;
ctx.nSharedMemPerBlock                 = props.sharedMemPerBlock;
ctx.nCudaDevAttrComputeCapabilityMajor = props.major;
ctx.nCudaDevAttrComputeCapabilityMinor = props.minor;
cudaStreamGetFlags(myStream, &ctx.nStreamFlags);
ctx.hWorkspace = 0;   // must be zero unless using nppiWorkspaceCreate()

Public Members

cudaStream_t hStream๏ƒ

From current Cuda stream ID.

int nCudaDeviceId๏ƒ

From cudaGetDevice().

int nMultiProcessorCount๏ƒ

From cudaGetDeviceProperties().

int nMaxThreadsPerMultiProcessor๏ƒ

From cudaGetDeviceProperties().

int nMaxThreadsPerBlock๏ƒ

From cudaGetDeviceProperties().

size_t nSharedMemPerBlock๏ƒ

From cudaGetDeviceProperties().

int nCudaDevAttrComputeCapabilityMajor๏ƒ

From cudaGetDeviceAttribute().

int nCudaDevAttrComputeCapabilityMinor๏ƒ

From cudaGetDeviceAttribute().

unsigned int nStreamFlags๏ƒ

From cudaStreamGetFlags().

NppWorkspace hWorkspace๏ƒ

Optional workspace handle; 0 = no workspace.

Set via nppiWorkspaceCreate().

Npp32u nReserved0๏ƒ

Deprecated:

Use hWorkspace. Same type and storage, kept for source compatibility with existing code that sets nReserved0 = 0.

union NppStreamContext.[anonymous] [anonymous]๏ƒ
struct NppiResizeBatchCXR๏ƒ

NPP Batch Geometry Structure Definitions.

Public Members

const void *pSrc๏ƒ

source image device memory pointer.

int nSrcStep๏ƒ

source image byte count per row.

void *pDst๏ƒ

destination image device memory pointer.

int nDstStep๏ƒ

device image byte count per row.

struct NppiResizeBatchROI_Advanced๏ƒ

Data structure for variable ROI image batch resizing.

Public Members

NppiRect oSrcRectROI๏ƒ

per source image rectangle parameters.

NppiRect oDstRectROI๏ƒ

per destination image rectangle parameters.

struct NppiMirrorBatchCXR๏ƒ

Data structure for batched nppiMirrorBatch.

Public Members

const void *pSrc๏ƒ

source image device memory pointer, ignored for in-place versions.

int nSrcStep๏ƒ

source image byte count per row.

void *pDst๏ƒ

destination image device memory pointer.

int nDstStep๏ƒ

device image byte count per row.

struct NppiWarpAffineBatchCXR๏ƒ

Data structure for batched nppiWarpAffineBatch.

Public Members

const void *pSrc๏ƒ

source image device memory pointer.

int nSrcStep๏ƒ

source image byte count per row.

void *pDst๏ƒ

destination image device memory pointer.

int nDstStep๏ƒ

device image byte count per row.

Npp64f *pCoeffs๏ƒ

device memory pointer to the tranformation matrix with double precision floating-point coefficient values to be used for this image.

Npp64f aTransformedCoeffs[2][3]๏ƒ

FOR INTERNAL USE, DO NOT INITIALIZE.

struct NppiWarpPerspectiveBatchCXR๏ƒ

Data structure for batched nppiWarpPerspectiveBatch.

Public Members

const void *pSrc๏ƒ

source image device memory pointer.

int nSrcStep๏ƒ

source image byte count per row.

void *pDst๏ƒ

destination image device memory pointer.

int nDstStep๏ƒ

device image byte count per row.

Npp64f *pCoeffs๏ƒ

device memory pointer to the tranformation matrix with double precision floating-point coefficient values to be used for this image.

Npp64f aTransformedCoeffs[3][3]๏ƒ

FOR INTERNAL USE, DO NOT INITIALIZE.

struct NppiColorTwistBatchCXR๏ƒ

Data structure for batched nppiColorTwistBatch.

Public Members

const void *pSrc๏ƒ

source image device memory pointer.

int nSrcStep๏ƒ

source image byte count per row.

void *pDst๏ƒ

destination image device memory pointer.

int nDstStep๏ƒ

device image byte count per row.

Npp32f *pTwist๏ƒ

device memory pointer to the color twist matrix with floating-point coefficient values to be used for this image.